Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3925)

Unified Diff: chrome/browser/password_manager/password_form_manager.h

Issue 10892011: Fix for no password save when action URL is modified (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/password_manager/password_form_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/password_manager/password_form_manager.h
===================================================================
--- chrome/browser/password_manager/password_form_manager.h (revision 157109)
+++ chrome/browser/password_manager/password_form_manager.h (working copy)
@@ -39,9 +39,16 @@
bool ssl_valid);
virtual ~PasswordFormManager();
- // Compare basic data of observed_form_ with argument.
- bool DoesManage(const webkit::forms::PasswordForm& form) const;
+ enum ActionMatch {
+ ACTION_MATCH_REQUIRED,
+ ACTION_MATCH_NOT_REQUIRED
+ };
+ // Compare basic data of observed_form_ with argument. Only check the action
+ // URL when action match is required.
+ bool DoesManage(const webkit::forms::PasswordForm& form,
+ ActionMatch action_match) const;
+
// Retrieves potential matching logins from the database.
void FetchMatchingLoginsFromPasswordStore();
« no previous file with comments | « no previous file | chrome/browser/password_manager/password_form_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698